@@ -27,6 +27,7 @@ from testrepository.repository import (
     AbstractRepository,
     AbstractRepositoryFactory,
     AbstractTestRun,
+    RepositoryNotFound,
     )
 
 
@@ -34,7 +35,7 @@ class RepositoryFactory(AbstractRepositoryFactory):
 
     def initialise(klass, url):
         """Create a repository at url/path."""
-        base = os.path.join(url, '.testrepository')
+        base = os.path.join(os.path.expanduser(url), '.testrepository')
         os.mkdir(base)
         stream = file(os.path.join(base, 'format'), 'wb')
         try:
@@ -46,8 +47,14 @@ class RepositoryFactory(AbstractRepositoryFactory):
         return result
 
     def open(self, url):
-        base = os.path.join(url, '.testrepository')
-        stream = file(os.path.join(base, 'format'), 'rb')
+        path = os.path.expanduser(url)
+        base = os.path.join(path, '.testrepository')
+        try:
+            stream = file(os.path.join(base, 'format'), 'rb')
+        except (IOError, OSError), e:
+            if e.errno == errno.ENOENT:
+                raise RepositoryNotFound(url)
+            raise
         if '1\n' != stream.read():
             raise ValueError(url)
         return Repository(base)
